Bug 491304 - rename testResultsRows.html to testResultsTables.html
diff --git a/bundles/org.eclipse.build.tools/src/org/eclipse/releng/generators/TestResultsGenerator.java b/bundles/org.eclipse.build.tools/src/org/eclipse/releng/generators/TestResultsGenerator.java
index afbefe4..a872bcb 100644
--- a/bundles/org.eclipse.build.tools/src/org/eclipse/releng/generators/TestResultsGenerator.java
+++ b/bundles/org.eclipse.build.tools/src/org/eclipse/releng/generators/TestResultsGenerator.java
@@ -208,7 +208,7 @@
     // Name of the HTML fragment file that any testResults.php file will
     // "include".
     // setting to common default.
-    private String              testResultsHtmlFileName        = "testResultsRows.html";
+    private String              testResultsHtmlFileName        = "testResultsTables.html";
 
     // Name of the generated drop index php file;
     private String              dropHtmlFileName;
@@ -370,7 +370,7 @@
 
             test.setDropTemplateFileName(
                     "/home/davidw/gitNeon/eclipse.platform.releng.aggregator/eclipse.platform.releng.tychoeclipsebuilder/eclipse/publishingFiles/templateFiles/index.template.php");
-            test.setTestResultsHtmlFileName("testResultsRows.html");
+            test.setTestResultsHtmlFileName("testResultsTables.html");
             test.setDropHtmlFileName("index.php");
 
             test.setHrefTestResultsTargetPath("testresults");
@@ -944,7 +944,7 @@
         // These first files reflect what we expected, and what we found.
         String found_config_type = "found";
         writePhpConfigFile(found_config_type, foundConfigs, FOUND_TEST_CONFIGS_FILENAME);
         // write the table to main output directory in testResultsRows.html,
         // which
         // in turn is included by the testResults.php file.
@@ -944,7 +944,7 @@
         String found_config_type = "found";
         writePhpConfigFile(found_config_type, foundConfigs, FOUND_TEST_CONFIGS_FILENAME);
-        // write the table to main output directory in testResultsRows.html,
+        // write the table to main output directory in testResultsTables.html,
         // which
         // in turn is included by the testResults.php file.